Learn R Programming

rbmi (version 1.6.1)

add_class: Add a class

Description

Utility function to add a class to an object. Adds the new class after any existing classes.

Usage

add_class(x, cls)

Value

x with cls appended after its existing class attribute.

Arguments

x

object to add a class to.

cls

the class to be added.