Skip to contents

Creates an analysis object ensuring that all components are correctly defined.

Usage

as_analysis(
  results,
  method,
  delta = NULL,
  fun = NULL,
  fun_name = NULL,
  par_meta = NULL
)

Arguments

results

A list of lists contain the analysis results for each imputation See analyse() for details on what this object should look like.

method

The method object as specified in draws().

delta

The delta dataset used. See analyse() for details on how this should be specified.

fun

The analysis function that was used.

fun_name

The character name of the analysis function (used for printing) purposes.

par_meta

Optional data.frame of per-parameter metadata (e.g. the group levels and visit associated with each analysis parameter) as attached by the analysis function. May be NULL.