Converts a numeric value of length 1 into a 1 dimension array.
This is to avoid type errors that are thrown by Stan when length 1 numeric vectors
are provided by R for stan::vector inputs
Converts a numeric value of length 1 into a 1 dimension array.
This is to avoid type errors that are thrown by Stan when length 1 numeric vectors
are provided by R for stan::vector inputs