extract_params: Extract parameters from a MMRM model

View source: R/mmrm.R

extract_paramsR Documentation

Extract parameters from a MMRM model

Description

Extracts the beta and sigma coefficients from an MMRM model created by mmrm::mmrm().

Usage

extract_params(fit)

Arguments

fit

an object created by mmrm::mmrm()

Details

For structured covariance models, additional parameter estimates will be returned, based on the type of the covariance model.


rbmi documentation built on July 23, 2026, 1:08 a.m.