| pool_internal | R Documentation |
Dispatches pool methods based upon results object class. See
pool() for details.
pool_internal(results, conf.level, alternative, type, D)
## S3 method for class 'jackknife'
pool_internal(results, conf.level, alternative, type, D)
## S3 method for class 'bootstrap'
pool_internal(
results,
conf.level,
alternative,
type = c("percentile", "normal"),
D
)
## S3 method for class 'bmlmi'
pool_internal(results, conf.level, alternative, type, D)
## S3 method for class 'rubin'
pool_internal(results, conf.level, alternative, type, D)
results |
a list of results i.e. the |
conf.level |
confidence level of the returned confidence interval. Must be a single number between 0 and 1. Default is 0.95. |
alternative |
a character string specifying the alternative hypothesis,
must be one of |
type |
a character string of either |
D |
numeric representing the number of imputations between each bootstrap sample in the BMLMI method. |
A list containing the pooled results for a single parameter with elements
est (point estimate), ci (confidence interval), se (standard error)
and pvalue (p-value). The specific computation is determined by the class
of results via S3 dispatch.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.