| rbmi-package | R Documentation |
The rbmi package is used to perform reference based multiple imputation. The package
provides implementations for common, patient-specific imputation strategies whilst allowing the user to
select between various standard Bayesian and frequentist approaches.
The package is designed around 4 core functions:
draws() - Fits multiple imputation models
impute() - Imputes multiple datasets
analyse() - Analyses multiple datasets
pool() - Pools multiple results into a single statistic
To learn more about rbmi, please see the quickstart vignette:
vignette(topic= "quickstart", package = "rbmi")
Maintainer: Lukas A. Widmer lukas_andreas.widmer@novartis.com (ORCID)
Authors:
Lukas A. Widmer lukas_andreas.widmer@novartis.com (ORCID)
Craig Gower-Page craig.gower-page@novartis.com
Isaac Gravestock isaac.gravestock@roche.com (ORCID)
Alessandro Noci alessandro.noci@roche.com
Marcel Wolbers marcel.wolbers@bayer.com (ORCID)
Daniel Sabanes Bove daniel.sabanes_bove@rconis.com (ORCID)
Other contributors:
F. Hoffmann-La Roche AG [copyright holder, funder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.