Utility function used to replicate purrr::reduce. Recursively applies a
function to a list of elements until only 1 element remains
Utility function used to replicate purrr::reduce. Recursively applies a
function to a list of elements until only 1 element remains