Utility function used to replicate str_pad. Adds white space to either end
of a string to get it to equal the desired length
Utility function used to replicate str_pad. Adds white space to either end
of a string to get it to equal the desired length