Checks that the required variable names are defined within vars and
are of appropriate data types
Usage
# S3 method for class 'ivars'
validate(x, ...)Checks that the required variable names are defined within vars and
are of appropriate data types
# S3 method for class 'ivars'
validate(x, ...)