| validate_analyse_pars | R Documentation |
Validates analysis results generated by analyse().
validate_analyse_pars(results, pars)
results |
A list of results generated by the analysis |
pars |
A list of expected parameters in each of the analysis.
lists i.e. |
TRUE (invisibly) if results conforms to the expected structure;
otherwise an error is thrown describing the first failed check.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.