| Stack | R Documentation |
This is a simple stack object offering add / pop functionality
A Stack generator object (an R6::R6Class generator). Call Stack$new()
to create an instance, which exposes add() and pop() methods for storing
and retrieving elements in first-in-first-out order.
stackA list containing the current stack
Stack$add()Adds content to the end of the stack (must be a list)
Stack$add(x)
xcontent to add to the stack
Stack$pop()Retrieve content from the stack
Stack$pop(i)
ithe number of items to retrieve from the stack. If there are less than i
items left on the stack it will just return everything that is left.
Stack$clone()The objects of this class are cloneable with this method.
Stack$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.