powered by
Utility function to add a class to an object. Adds the new class after any existing classes.
add_class(x, cls)
x with cls appended after its existing class attribute.
x
cls
object to add a class to.
the class to be added.