This function is used to perform assertions that an object conforms to its expected structure and no basic assumptions have been violated. Will throw an error if checks do not pass.
validate(x, ...)Called for its side effect of validating x. Throws an error if any check
fails; otherwise returns invisibly (the exact value depends on the method,
typically invisible(TRUE) or invisible(NULL)).
object to be validated.
additional arguments to pass to the specific validation method.