Validates analysis results generated by analyse().
validate_analyse_pars(results, pars)TRUE (invisibly) if results conforms to the expected structure;
otherwise an error is thrown describing the first failed check.
A list of results generated by the analysis fun
used in analyse().
A list of expected parameters in each of the analysis.
lists i.e. c("est", "se", "df").